@@ -221,6 +221,7 @@ public:
    bool bdb_get_pool_record(JCR *jcr, POOL_DBR *pdbr);
    bool bdb_get_pool_numvols(JCR *jcr, POOL_DBR *pdbr);
    int bdb_get_client_record(JCR *jcr, CLIENT_DBR *cr);
+   bool bdb_get_jobmedia_record(JCR *jcr, JOBMEDIA_DBR *jmr);
    bool bdb_get_job_record(JCR *jcr, JOB_DBR *jr);
    int bdb_get_job_volume_names(JCR *jcr, JobId_t JobId, POOLMEM **VolumeNames);
    bool bdb_get_file_attributes_record(JCR *jcr, char *fname, JOB_DBR *jr, FILE_DBR *fdbr);
@@ -243,6 +244,7 @@ public:
    bool bdb_get_restoreobject_record(JCR *jcr, ROBJECT_DBR *rr);
    int  bdb_get_num_restoreobject_records(JCR *jcr, ROBJECT_DBR *rr);
    bool bdb_get_job_statistics(JCR *jcr, JOB_DBR *jr);
+   bool bdb_get_client_pool(JCR *jcr, alist *results);
 
 /* sql_list.c */
    void bdb_list_pool_records(JCR *jcr, POOL_DBR *pr, DB_LIST_HANDLER sendit, void *ctx, e_list_type type);
