@@ -1,7 +1,7 @@
 /* 
    Bacula(R) - The Network Backup Solution
 
-   Copyright (C) 2000-2017 Kern Sibbald
+   Copyright (C) 2000-2018 Kern Sibbald
 
    The original author of Bacula is Kern Sibbald, with contributions
    from many others, a complete list can be found in the file AUTHORS.
@@ -198,7 +198,7 @@ bool BDB_MYSQL::bdb_open_database(JCR *jcr)
    BDB_MYSQL *mdb = this; 
    bool retval = false; 
    int errstat; 
-   my_bool reconnect = 1;
+   bool reconnect = true;
  
    P(mutex); 
    if (mdb->m_connected) { 
@@ -458,13 +458,6 @@ void BDB_MYSQL::bdb_start_transaction(JCR *jcr)
  
 void BDB_MYSQL::bdb_end_transaction(JCR *jcr) 
 { 
-   if (jcr && jcr->cached_attribute) { 
-      Dmsg0(400, "Flush last cached attribute.\n"); 
-      if (!bdb_create_attributes_record(jcr, jcr->ar)) { 
-         Jmsg1(jcr, M_FATAL, 0, _("Attribute create error. %s"), jcr->db->bdb_strerror()); 
-      } 
-      jcr->cached_attribute = false; 
-   } 
 } 
  
 /* 
