@@ -89,4 +89,22 @@ extern const char CATS_IMP_EXP *update_counter_values[];
 extern const char CATS_IMP_EXP *expires_in[];
 extern const char CATS_IMP_EXP *prune_cache[];
 extern const char CATS_IMP_EXP *strip_restore[];
+extern const char CATS_IMP_EXP *count_all_jobs;
+extern const char CATS_IMP_EXP *count_success_jobs;
+extern const char CATS_IMP_EXP *count_success_jobids;
+extern const char CATS_IMP_EXP *count_error_jobs;
+extern const char CATS_IMP_EXP *count_error_jobids;
+extern const char CATS_IMP_EXP *count_warning_jobs;
+extern const char CATS_IMP_EXP *count_warning_jobids;
+extern const char CATS_IMP_EXP *sum_jobs_bytes;
+extern const char CATS_IMP_EXP *sum_jobids_bytes;
+extern const char CATS_IMP_EXP *sum_jobs_files;
+extern const char CATS_IMP_EXP *sum_jobids_files;
+extern const char CATS_IMP_EXP *count_all_volumes;
+extern const char CATS_IMP_EXP *count_avl_volumes;
+extern const char CATS_IMP_EXP *count_error_volumes;
+extern const char CATS_IMP_EXP *count_full_volumes;
+extern const char CATS_IMP_EXP *count_used_volumes;
+extern const char CATS_IMP_EXP *sum_volumes_bytes;
+extern const char CATS_IMP_EXP *get_volume_size;
 extern const char CATS_IMP_EXP *escape_char_value[];
