@@ -409,6 +409,8 @@ static int tls_pem_callback(char *buf, int size, const void *userdata)
 #include "readline.h"
 #include "history.h"
 
+static int history_lines_added=0; /* Number of lines added to the history file */
+
 /* Get the first keyword of the line */
 static char *
 get_first_keyword()
@@ -486,9 +488,7 @@ static ItemList *items = NULL;
 void init_items()
 {
    if (!items) {
-      items = (ItemList*) malloc(sizeof(ItemList));
-      memset(items, 0, sizeof(ItemList));
-
+      items = (ItemList*)bmalloc(sizeof(ItemList));  /* bmalloc clears memory */
    } else {
       items->list.destroy();
    }
@@ -657,7 +657,8 @@ static struct cpl_keywords_t cpl_keywords[] = {
    {"actiononpurge=", ".actiononpurge" },
    {"tags=",      ".tags"          },
    {"recylepool=", ".pool"         },
-   {"allfrompool=",".pool"         }
+   {"allfrompool=",".pool"         },
+   {"nextpool=",   ".pool"         }
 };
 #define key_size ((int)(sizeof(cpl_keywords)/sizeof(struct cpl_keywords_t)))
 
@@ -789,6 +790,10 @@ get_cmd(FILE *input, const char *prompt, BSOCK *sock, int sec)
    if (!next) {
       if (do_history) {
         add_history(line);
+        /* Count the number of lines added, we use it to truncate the history 
+         * file correctly
+         */
+        history_lines_added++;
       }
       actuallyfree(line);       /* allocated by readline() malloc */
       line = NULL;
@@ -928,6 +933,10 @@ void trapctlc()
    signal(SIGINT, sigintcatcher);
 }
 
+#ifdef HAVE_READLINE
+static int histfile_size = 100;
+#endif
+
 static int console_update_history(const char *histfile)
 {
    int ret=0;
@@ -938,9 +947,10 @@ static int console_update_history(const char *histfile)
  * fails, the file is probably not present, and we
  * can use write_history to create it
  */
-
-   if (history_truncate_file(histfile, 100) == 0) {
-      ret = append_history(history_length, histfile);
+   int nlines = MAX(histfile_size - history_lines_added, 0);
+   if (history_truncate_file(histfile, nlines) == 0) {
+      nlines = MIN(histfile_size, history_lines_added);
+      ret = append_history(nlines, histfile);
    } else {
       ret = write_history(histfile);
    }
@@ -1247,7 +1257,7 @@ int main(int argc, char *argv[])
       exit(0);
    }
 
-   memset(&jcr, 0, sizeof(jcr));
+   memset((void *)&jcr, 0, sizeof(jcr));
 
    (void)WSA_Init();                        /* Initialize Windows sockets */
 
