@@ -632,7 +632,7 @@ bool send_include_list(JCR *jcr)
 }
 
 /*
- * Send a include list with a plugin and listing=<path> parameter
+ * Send an include list with a plugin and listing=<path> parameter
  */
 bool send_ls_plugin_fileset(JCR *jcr, const char *plugin, const char *path)
 {
@@ -642,7 +642,7 @@ bool send_ls_plugin_fileset(JCR *jcr, const char *plugin, const char *path)
    fd->fsend("I\n");
    fd->fsend("O h\n");         /* is it required? */
    fd->fsend("N\n");
-   fd->fsend("P %s listing=%s\n", plugin, path);
+   fd->fsend("P %s%s listing=%s\n", plugin, strchr(plugin, ':') == NULL ? ":" : "", path);
    fd->fsend("N\n");
    fd->signal(BNET_EOD);              /* end of data */
 
@@ -937,7 +937,7 @@ int get_attributes_and_put_in_catalog(JCR *jcr)
    BSOCK   *fd;
    int n = 0;
    ATTR_DBR *ar = NULL;
-   char digest[MAXSTRING];
+   char digest[2*(MAXSTRING+1)+1];  /* escaped version of Digest */
 
    fd = jcr->file_bsock;
    jcr->jr.FirstIndex = 1;
@@ -952,7 +952,7 @@ int get_attributes_and_put_in_catalog(JCR *jcr)
       int32_t file_index;
       int stream, len;
       char *p, *fn;
-      char Digest[MAXSTRING];      /* either Verify opts or MD5/SHA1 digest */
+      char Digest[MAXSTRING+1];      /* either Verify opts or MD5/SHA1 digest */
 
       /* Stop here if canceled */
       if (jcr->is_job_canceled()) {
@@ -960,7 +960,7 @@ int get_attributes_and_put_in_catalog(JCR *jcr)
          return 0;
       }
 
-      if ((len = sscanf(fd->msg, "%ld %d %s", &file_index, &stream, Digest)) != 3) {
+      if ((len = sscanf(fd->msg, "%ld %d %500s", &file_index, &stream, Digest)) != 3) { /* MAXSTRING */
          Jmsg(jcr, M_FATAL, 0, _("<filed: bad attributes, expected 3 fields got %d\n"
 "msglen=%d msg=%s\n"), len, fd->msglen, fd->msg);
          jcr->setJobStatus(JS_ErrorTerminated);
