@@ -84,6 +84,7 @@ extern bool despool_attributes_from_file(JCR *jcr, const char *file);
 extern void remove_dummy_jobmedia_records(JCR *jcr);
 
 /* dird_conf.c */
+extern const char *level_to_static_str(int level);
 extern char *level_to_str(char *buf, int len, int level);
 extern "C" char *job_code_callback_director(JCR *jcr, const char*, char *, int);
 
@@ -360,3 +361,10 @@ int  delete_snapshot(UAContext *ua);
 bool update_snapshot(UAContext *ua);
 int prune_snapshot(UAContext *ua);
 bool send_snapshot_retention(JCR *jcr, utime_t val);
+
+/* ua_collect.c */
+bool update_permanent_stats(void *data);
+void initialize_statcollector();
+void start_collector_threads();
+void terminate_collector_threads();
+void update_config_stats();
