@@ -11,7 +11,7 @@
    Public License, v3.0 ("AGPLv3") and some additional permissions and
    terms pursuant to its AGPLv3 Section 7.
 
-   This notice must be preserved when any source code is 
+   This notice must be preserved when any source code is
    conveyed and/or propagated.
 
    Bacula(R) is a registered trademark of Kern Sibbald.
@@ -413,6 +413,8 @@ static void dump_json(display_filter *filter)
                   display_cipher(hpkt);
                } else if (items[item].handler == store_digest_type) {
                   display_digest(hpkt);
+               } else if (items[item].handler == store_coll_type) {
+                  display_collector_types(hpkt);
                } else {
                   printf("\n    \"%s\": null", items[item].name);
                }
