@@ -39,28 +39,29 @@ static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
 
 #ifdef HAVE_WIN32
 const bool have_win32 = true;
-#else 
+#else
 const bool have_win32 = false;
 #endif
 
 #ifdef HAVE_ACL
-const bool have_acl = true; 
-#else 
-const bool have_acl = false; 
-#endif 
+const bool have_acl = true;
+#else
+const bool have_acl = false;
+#endif
 
 #if HAVE_XATTR
-const bool have_xattr = true; 
-#else 
-const bool have_xattr = false; 
-#endif 
- 
+const bool have_xattr = true;
+#else
+const bool have_xattr = false;
+#endif
+
 extern CLIENT *me;                    /* our client resource */
 
 /* Imported functions */
 extern int status_cmd(JCR *jcr);
 extern int qstatus_cmd(JCR *jcr);
 extern int accurate_cmd(JCR *jcr);
+extern int collect_cmd(JCR *jcr);
 
 /* Forward referenced functions */
 static int backup_cmd(JCR *jcr);
@@ -79,7 +80,6 @@ static int end_restore_cmd(JCR *jcr);
 static int storage_cmd(JCR *jcr);
 static int session_cmd(JCR *jcr);
 static int response(JCR *jcr, BSOCK *sd, char *resp, const char *cmd);
-static void filed_free_jcr(JCR *jcr);
 static int open_sd_read_session(JCR *jcr);
 static int runscript_cmd(JCR *jcr);
 static int runbefore_cmd(JCR *jcr);
@@ -132,6 +132,7 @@ struct s_cmds cmds[] = {
    {"stop",         cancel_cmd,  ACCESS_REMOTE},
    {"proxy",        proxy_cmd,   ACCESS_REMOTE},
    {"testnetwork",  fd_testnetwork_cmd, 0},
+   {"statistics",   collect_cmd, 0},
 #ifdef DEVELOPER
    {"exit",         exit_cmd, 0},
 #endif
@@ -271,8 +272,9 @@ static void *handle_director_request(BSOCK *dir)
    bool first = true;
    JCR *jcr;
    const char jobname[12] = "*Director*";
+   suspendres_t suspend;
 
-   prevent_os_suspensions();   /* do not suspend during backup/restore */
+   prevent_os_suspensions(suspend);   /* do not suspend during backup/restore */
    jcr = new_jcr(sizeof(JCR), filed_free_jcr); /* create JCR */
    jcr->sd_calls_client_bsock = NULL;
    jcr->sd_calls_client = false;
@@ -303,6 +305,7 @@ static void *handle_director_request(BSOCK *dir)
    enable_backup_privileges(NULL, 1 /* ignore_errors */);
 
    for (quit=false; !quit;) {
+      jcr->buf_size = DEFAULT_NETWORK_BUFFER_SIZE;  /* overriden by some commands */
       if (!first) {      /* first call the read is done */
          /* Read command */
          if (dir->recv() < 0) {
@@ -314,7 +317,7 @@ static void *handle_director_request(BSOCK *dir)
       }
       first = false;
       dir->msg[dir->msglen] = 0;
-      Dmsg1(100, "<dird: %s", dir->msg);
+      Dmsg1(100, "<dird: %s\n", dir->msg);
       found = false;
       for (i=0; cmds[i].cmd; i++) {
          if (strncmp(cmds[i].cmd, dir->msg, strlen(cmds[i].cmd)) == 0) {
@@ -471,7 +474,7 @@ bail_out:
    pthread_cond_destroy(&jcr->job_start_wait);
    free_jcr(jcr);                     /* destroy JCR record */
    Dmsg0(100, "Done with free_jcr\n");
-   allow_os_suspensions();            /* FD can now be suspended */
+   allow_os_suspensions(suspend);            /* FD can now be suspended */
    Dsm_check(100);
    garbage_collect_memory_pool();
    return NULL;
@@ -512,7 +515,7 @@ bail_out:
 }
 
 
-/* 
+/*
  * Test the Network between FD/SD
  */
 static int fd_testnetwork_cmd(JCR *jcr)
@@ -607,7 +610,7 @@ static int proxy_cmd(JCR *jcr)
    /* Inform the console that the command is OK */
    jcr->dir_bsock->fsend("2000 proxy OK.\n");
    jcr->dir_bsock->signal(BNET_MAIN_PROMPT);
-   
+
    maxfd = MAX(cons_bsock->m_fd, jcr->dir_bsock->m_fd) + 1;
 
    /* Start to forward events from one to the other
@@ -676,7 +679,7 @@ static int proxy_cmd(JCR *jcr)
          OK = false;
       }
    } while (OK && !jcr->is_canceled());
-   
+
    /* Close the socket, nothing more will come */
    jcr->dir_bsock->signal(BNET_TERMINATE);
    jcr->dir_bsock->close();
@@ -1177,8 +1180,7 @@ static bool init_fileset(JCR *jcr)
    if (ff->fileset) {
       return false;
    }
-   fileset = (findFILESET *)malloc(sizeof(findFILESET));
-   memset(fileset, 0, sizeof(findFILESET));
+   fileset = (findFILESET *)bmalloc(sizeof(findFILESET));
    ff->fileset = fileset;
    fileset->state = state_none;
    fileset->include_list.init(1, true);
@@ -1304,8 +1306,7 @@ findINCEXE *new_exclude(JCR *jcr)
    findFILESET *fileset = jcr->ff->fileset;
 
    /* New exclude */
-   fileset->incexe = (findINCEXE *)malloc(sizeof(findINCEXE));
-   memset(fileset->incexe, 0, sizeof(findINCEXE));
+   fileset->incexe = (findINCEXE *)bmalloc(sizeof(findINCEXE));
    fileset->incexe->opts_list.init(1, true);
    fileset->incexe->name_list.init();
    fileset->incexe->plugin_list.init();
@@ -1321,8 +1322,7 @@ findINCEXE *new_include(JCR *jcr)
    findFILESET *fileset = jcr->ff->fileset;
 
    /* New include */
-   fileset->incexe = (findINCEXE *)malloc(sizeof(findINCEXE));
-   memset(fileset->incexe, 0, sizeof(findINCEXE));
+   fileset->incexe = (findINCEXE *)bmalloc(sizeof(findINCEXE));
    fileset->incexe->opts_list.init(1, true);
    fileset->incexe->name_list.init(); /* for dlist;  was 1,true for alist */
    fileset->incexe->plugin_list.init();
@@ -1340,8 +1340,7 @@ findINCEXE *new_preinclude(JCR *jcr)
    findFILESET *fileset = jcr->ff->fileset;
 
    /* New pre-include */
-   fileset->incexe = (findINCEXE *)malloc(sizeof(findINCEXE));
-   memset(fileset->incexe, 0, sizeof(findINCEXE));
+   fileset->incexe = (findINCEXE *)bmalloc(sizeof(findINCEXE));
    fileset->incexe->opts_list.init(1, true);
    fileset->incexe->name_list.init(); /* for dlist;  was 1,true for alist */
    fileset->incexe->plugin_list.init();
@@ -1356,8 +1355,7 @@ static findFOPTS *start_options(FF_PKT *ff)
 
    if (state != state_options) {
       ff->fileset->state = state_options;
-      findFOPTS *fo = (findFOPTS *)malloc(sizeof(findFOPTS));
-      memset(fo, 0, sizeof(findFOPTS));
+      findFOPTS *fo = (findFOPTS *)bmalloc(sizeof(findFOPTS));
       fo->regex.init(1, true);
       fo->regexdir.init(1, true);
       fo->regexfile.init(1, true);
@@ -1382,8 +1380,7 @@ void new_options(JCR *jcr, findINCEXE *incexe)
    if (!incexe) {
       incexe = jcr->ff->fileset->incexe;
    }
-   findFOPTS *fo = (findFOPTS *)malloc(sizeof(findFOPTS));
-   memset(fo, 0, sizeof(findFOPTS));
+   findFOPTS *fo = (findFOPTS *)bmalloc(sizeof(findFOPTS));
    fo->regex.init(1, true);
    fo->regexdir.init(1, true);
    fo->regexfile.init(1, true);
@@ -1973,7 +1970,7 @@ static int level_cmd(JCR *jcr)
          if (dir->recv() <= 0) {      /* get response */
             goto bail_out;
          }
-         if (sscanf(dir->msg, "btime %s", buf) != 1) {
+         if (sscanf(dir->msg, "btime %50s", buf) != 1) {
             goto bail_out;
          }
          his_time = str_to_uint64(buf);
@@ -2409,15 +2406,15 @@ static int backup_cmd(JCR *jcr)
    /*
     * If explicitly requesting FO_ACL or FO_XATTR, fail job if it
     *  is not available on Client machine
-    */ 
+    */
    if (jcr->ff->flags & FO_ACL && !(have_acl||have_win32)) {
       Jmsg(jcr, M_FATAL, 0, _("ACL support not configured for Client.\n"));
-      goto cleanup; 
-   } 
-   if (jcr->ff->flags & FO_XATTR && !have_xattr) { 
+      goto cleanup;
+   }
+   if (jcr->ff->flags & FO_XATTR && !have_xattr) {
       Jmsg(jcr, M_FATAL, 0, _("XATTR support not configured for Client.\n"));
-      goto cleanup; 
-   } 
+      goto cleanup;
+   }
    jcr->setJobStatus(JS_Blocked);
    jcr->setJobType(JT_BACKUP);
    Dmsg1(100, "begin backup ff=%p\n", jcr->ff);
@@ -2952,7 +2949,7 @@ static int open_sd_read_session(JCR *jcr)
  * Destroy the Job Control Record and associated
  * resources (sockets).
  */
-static void filed_free_jcr(JCR *jcr)
+void filed_free_jcr(JCR *jcr)
 {
    if (jcr->dir_bsock) {
       free_bsock(jcr->dir_bsock);
