@@ -366,7 +366,7 @@ void do_restore(JCR *jcr)
    /* ***FIXME*** make configurable */
    crypto_digest_t signing_algorithm = have_sha2 ?
                                        CRYPTO_DIGEST_SHA256 : CRYPTO_DIGEST_SHA1;
-   memset(&rctx, 0, sizeof(rctx));
+   memset((void *)&rctx, 0, sizeof(rctx));
    rctx.jcr = jcr;
 
    /* The following variables keep track of "known unknowns" */
@@ -1766,6 +1766,7 @@ static bool verify_signature(r_ctx &rctx)
                Jmsg(jcr, M_ERROR, 0, _("Digest one file failed for file: %s\n"),
                     jcr->last_fname);
                jcr->JobBytes = saved_bytes;
+               jcr->crypto.digest = NULL;
                goto get_out;
             }
             jcr->JobBytes = saved_bytes;
@@ -1775,6 +1776,7 @@ static bool verify_signature(r_ctx &rctx)
                Dmsg1(50, "Bad signature on %s\n", jcr->last_fname);
                Jmsg2(jcr, M_ERROR, 0, _("Signature validation failed for file %s: ERR=%s\n"),
                      jcr->last_fname, crypto_strerror(err));
+               jcr->crypto.digest = NULL;
                goto get_out;
             }
             jcr->crypto.digest = NULL;
