@@ -218,6 +218,9 @@ int bmicrosleep(int32_t sec, int32_t usec)
    return stat;
 }
 
+/* allow using strncpy in this file */
+#undef strncpy
+
 /*
  * Guarantee that the string is properly terminated */
 char *bstrncpy(char *dest, const char *src, int maxlen)
@@ -964,20 +967,7 @@ char *escape_filename(const char *file_path)
    return escaped_path;
 }
 
-/*
- * For the moment preventing suspensions is only
- *  implemented on Windows.
- */
-#ifndef HAVE_WIN32
-void prevent_os_suspensions()
-{ }
-
-void allow_os_suspensions()
-{ }
-#endif
-
-
-#if HAVE_BACKTRACE && HAVE_GCC
+#if HAVE_BACKTRACE && HAVE_GCC && HAVE_LINUX_OS
 /* if some names are not resolved you can try using : addr2line, like this
  * $ addr2line -e bin/bacula-sd -a 0x43cd11
  * OR
@@ -1020,7 +1010,7 @@ void stack_trace()
             function = ret;
          } else {
             /* demangling failed, just pretend it's a C function with no args */
-            strncpy(function, begin, sz);
+            bstrncpy(function, begin, sz);
             strncat(function, "()", sz);
             function[sz-1] = '\0';
          }
@@ -1089,7 +1079,7 @@ void setup_env(char *envp[])
    }
 }
 
-/* Small function to copy a file somewhere else, 
+/* Small function to copy a file somewhere else,
  * for debug purpose.
  */
 int copyfile(const char *src, const char *dst)
@@ -1432,7 +1422,7 @@ int main(int argc, char **argv)
    int maxfd = (argc == 3) ? atoi(argv[2]) : 0;
 
    j = MIN(10000, j);
-   
+
    lmgr_init_thread();
    set_debug_flags((char *)"h");
 
