@@ -11,7 +11,7 @@
    Public License, v3.0 ("AGPLv3") and some additional permissions and
    terms pursuant to its AGPLv3 Section 7.
 
-   This notice must be preserved when any source code is 
+   This notice must be preserved when any source code is
    conveyed and/or propagated.
 
    Bacula(R) is a registered trademark of Kern Sibbald.
@@ -65,6 +65,7 @@
 union URES {
    MSGS  res_msgs;
    RES hdr;
+   COLLECTOR  res_collector;
 };
 
 #if defined(_MSC_VER)
@@ -114,6 +115,25 @@ RES_ITEM msgs_items[] = {
    {NULL,          NULL,       {0},       0, 0, 0}
 };
 
+/*
+ * Statistics resource directives
+ *
+ *  name         handler      value       code   flags  default_value
+ */
+RES_ITEM collector_items[] = {
+   {"Name",             store_name,       ITEM(res_collector.hdr.name),          0, ITEM_REQUIRED, 0},
+   {"Description",      store_str,        ITEM(res_collector.hdr.desc),          0, 0, 0},
+   {"Prefix",           store_str,        ITEM(res_collector.prefix),            0, 0, 0},
+   {"Metrics",          store_alist_str,  ITEM(res_collector.metrics),           0, 0, 0},   /* default all */
+   {"Interval",         store_time,       ITEM(res_collector.interval),          0, ITEM_DEFAULT, 5*60}, /* default 5 min */
+   {"Port",             store_pint32,     ITEM(res_collector.port),              0, 0, 0},
+   {"Host",             store_str,        ITEM(res_collector.host),              0, 0, 0},
+   {"Type",             store_coll_type,  ITEM(res_collector.type),              0, ITEM_REQUIRED, 0},
+   {"File",             store_str,        ITEM(res_collector.file),              0, 0, 0},
+   {"MangleMetric",     store_bool,       ITEM(res_collector.mangle_name),       0, 0, 0},
+   {NULL,               NULL,             {0},                                   0, 0, 0}
+};
+
 /* Various message types */
 s_kw msg_types[] = {
    {"Debug",         M_DEBUG},  /* Keep 1st place */
@@ -150,6 +170,18 @@ s_kw tapelabels[] = {
 };
 
 
+/*
+ * Keywords (RHS) permitted in Statistics type records
+ *
+ *   type_name       backend_type
+ */
+s_collt collectortypes[] = {
+   {"CSV",           COLLECTOR_BACKEND_CSV},
+   {"Graphite",      COLLECTOR_BACKEND_Graphite},
+   {NULL,            0}
+};
+
+
 /* Simply print a message */
 static void prtmsg(void *sock, const char *fmt, ...)
 {
@@ -220,11 +252,11 @@ bool CONFIG::insert_res(int rindex, int size)
  * Initialize the static structure to zeros, then
  *  apply all the default values.
  */
-static void init_resource(CONFIG *config, int type, RES_ITEM *items, int pass)
+static void init_resource0(CONFIG *config, int type, RES_ITEM *items, int pass)
 {
    int i;
    int rindex = type - r_first;
-   
+
    memset(config->m_res_all, 0, config->m_res_all_size);
    res_all.hdr.rcode = type;
    res_all.hdr.refcnt = 1;
@@ -263,7 +295,7 @@ static void init_resource(CONFIG *config, int type, RES_ITEM *items, int pass)
 }
 
 /* Initialize a resouce with default values */
-bool init_resource(CONFIG *config, uint32_t type, void *res)
+bool init_resource(CONFIG *config, uint32_t type, void *res, int size)
 {
    RES_ITEM *items;
    for (int i=0; resources[i].name; i++) {
@@ -272,8 +304,8 @@ bool init_resource(CONFIG *config, uint32_t type, void *res)
          if (!items) {
             return false;
          }
-         init_resource(config, type, items, 1);
-         memcpy(res, config->m_res_all, config->m_res_all_size);
+         init_resource0(config, type, items, 1);
+         memcpy(res, config->m_res_all, size);
          return true;
       }
    }
@@ -930,6 +962,28 @@ void store_label(LEX *lc, RES_ITEM *item, int index, int pass)
    set_bit(index, res_all.hdr.item_present);
 }
 
+/*
+ * Store Statistics Type (CSV, Graphite - only supported)
+ */
+void store_coll_type(LEX *lc, RES_ITEM *item, int index, int pass)
+{
+   int i;
+
+   lex_get_token(lc, T_NAME);
+   /* Store the type both pass 1 and pass 2 */
+   for (i = 0; collectortypes[i].type_name; i++) {
+      if (strcasecmp(lc->str, collectortypes[i].type_name) == 0) {
+         *(int32_t *)(item->value) = collectortypes[i].coll_type;
+         i = 0;
+         break;
+      }
+   }
+   if (i != 0) {
+      scan_err1(lc, _("Expected a Statistics backend type keyword, got: %s"), lc->str);
+   }
+   scan_to_eol(lc);
+   set_bit(index, res_all.hdr.item_present);
+}
 
 /* Parser state */
 enum parse_state {
@@ -1053,7 +1107,7 @@ bool CONFIG::parse_config()
                   }
                   state = p_resource;
                   res_type = resources[i].rcode;
-                  init_resource(this, res_type, items, pass);
+                  init_resource0(this, res_type, items, pass);
                   break;
                }
             }
