@@ -214,7 +214,7 @@ char *asciidump(const char *data, int len, char *buf, int capacity)
    char *b=buf;
    const unsigned char *p=(const unsigned char *)data;
    if (!data) {
-      strncpy(buf, "<NULL>", capacity);
+      bstrncpy(buf, "<NULL>", capacity);
       return buf;
    }
    while (len>0 && capacity>1) {
@@ -242,7 +242,7 @@ char *smartdump(const char *data, int len, char *buf, int capacity, bool *is_asc
    int c=capacity;
    const unsigned char *p=(const unsigned char *)data;
    if (!data) {
-      strncpy(buf, "<NULL>", capacity);
+      bstrncpy(buf, "<NULL>", capacity);
       return buf;
    }
    if (is_ascii != NULL) {
