@@ -85,6 +85,19 @@ typedef void (alert_cb)(void *alert_ctx, const char *short_msg,
    const char *long_msg, char *Volume, int severity,
    int flags, int alert, utime_t alert_time);
 
+/* registered device metrics */
+typedef struct {
+   int bacula_storage_device_freespace;
+   int bacula_storage_device_totalspace;
+   int bacula_storage_device_readbytes;
+   int bacula_storage_device_readtime;
+   int bacula_storage_device_readspeed;
+   int bacula_storage_device_writespeed;
+   int bacula_storage_device_status;
+   int bacula_storage_device_writebytes;
+   int bacula_storage_device_writetime;
+} devstatmetrics_t;
+
 /* Aligned Data Disk Volume extension */
 #define ADATA_EXTENSION ".add"
 
@@ -127,6 +140,7 @@ typedef void (alert_cb)(void *alert_ctx, const char *short_msg,
 #define CAP_CHECKLABELS    (1<<22)    /* Check for ANSI/IBM labels */
 #define CAP_BLOCKCHECKSUM  (1<<23)    /* Create/test block checksum */
 #define CAP_LSEEK          (1<<24)    /* Has lseek function defined i.e. basically File storage */
+#define CAP_SYNCONCLOSE    (1<<25)    /* Need to call fsync() when releasing/closing the device */
 
 /* Test state */
 #define dev_state(dev, st_state) ((dev)->state & (st_state))
@@ -335,8 +349,9 @@ public:
    int rem_wait_sec;
    int num_wait;
 
-   btime_t last_timer;         /* used by read/write/seek to get stats (usec) */
-   btime_t last_tick;          /* contains last read/write time (usec) */
+   btime_t last_timer;           /* used by read/write/seek to get stats (usec) */
+   btime_t last_tick;            /* contains last read/write time (usec) */
+   utime_t last_stat_timer;      /* used by update_permanent_stats() to count throughput */
 
    btime_t  DevReadTime;
    btime_t  DevWriteTime;
@@ -344,6 +359,12 @@ public:
    uint64_t DevReadBytes;
    uint64_t usage;             /* Drive usage read+write bytes */
 
+   uint64_t last_stat_DevWriteBytes;
+   uint64_t last_stat_DevReadBytes;
+
+   devstatmetrics_t devstatmetrics;    /* these are a device metrics for every device */
+   bstatcollect *devstatcollector;        /* a pointer to daemon's statcollector */
+
    /* Methods */
    btime_t get_timer_count(); /* return the last timer interval (ms) */
 
@@ -533,6 +554,7 @@ public:
    virtual bool open_device(DCR *dcr, int omode) = 0;
    virtual bool open_next_part(DCR *dcr);
    virtual bool close(DCR *dcr);                /* in dev.c */
+   virtual bool sync_data(DCR *dcr);            /* in dev.c */
    virtual void term(DCR *dcr);                 /* in dev.c */
    virtual bool close_part(DCR *dcr);
    virtual bool reposition(DCR *dcr, uint64_t raddr);
@@ -552,7 +574,7 @@ public:
    virtual bool weof(DCR *dcr, int num);        /* in dev.c */
    virtual bool end_of_volume(DCR *dcr) { return true; };
    virtual bool start_of_job(DCR *dcr) {return true; };
-   virtual bool end_of_job(DCR *dcr) {return true; };
+   virtual bool end_of_job(DCR *dcr, uint32_t truncate) {Enter(50); return true; };
    virtual bool is_indexed() { return true; };
    virtual void set_ateof();                    /* in dev.c */
    virtual const char *print_type() = 0;        /* in dev.c */
@@ -595,7 +617,7 @@ public:
    virtual void select_data_stream(DCR *dcr, DEV_RECORD *rec) { return; };
    virtual bool flush_block(DCR *dcr);    /* in block_util.c */
    virtual bool do_pre_write_checks(DCR *dcr, DEV_RECORD *rec) { return true; };
-
+   virtual void register_metrics(bstatcollect *collector);
 
    /*
     * Locking and blocking calls
