@@ -5,25 +5,26 @@
 #define COMMUNITY 1      /* Define to create a Windows community binary */
 
 /* Note: there can be only *one* VERSION in this file */
-#define VERSION "9.4.4"
-#define BDATE   "28 May 2019"
-#define LSMDATE "28May19"
+#define VERSION "9.6.5"
+#define BDATE   "11 June 2020"
+#define LSMDATE "11Jun20"
 
 #define RELEASE 1   /* Use ONLY in rpms */
 
-#define PROG_COPYRIGHT "Copyright (C) %d-2019 Kern Sibbald.\n"
-#define BYEAR "2019"       /* year for copyright messages in progs */
+#define PROG_COPYRIGHT "Copyright (C) %d-2020 Kern Sibbald.\n"
+#define BYEAR "2020"       /* year for copyright messages in progs */
 
 /*
  * Versions of packages needed to build Bacula components
  */
 #define DEPKGS_QT_VERSION  "01Jan13"
 #define DEPKGS_VERSION     "10Oct18"
+#define DOCKER_TAR_IMAGE   "19Aug19"
 
 /*
    Bacula(R) - The Network Backup Solution
 
-   Copyright (C) 2000-2019 Kern Sibbald
+   Copyright (C) 2000-2020 Kern Sibbald
 
    The original author of Bacula is Kern Sibbald, with contributions
    from many others, a complete list can be found in the file AUTHORS.
